]> granicus.if.org Git - python/commitdiff
Following Nick's suggestion, rename posix.fdlistdir() to posix.flistdir(), to
authorCharles-François Natali <neologix@free.fr>
Mon, 6 Feb 2012 18:54:48 +0000 (19:54 +0100)
committerCharles-François Natali <neologix@free.fr>
Mon, 6 Feb 2012 18:54:48 +0000 (19:54 +0100)
be consistent with other functions accepting file descriptors (fdlistdir() was
added in 3.3, so hasn't been released yet).

Doc/library/os.rst
Doc/whatsnew/3.3.rst
Lib/os.py
Lib/test/test_os.py
Lib/test/test_posix.py
Misc/NEWS
Modules/posixmodule.c

index 8601687227f9b26a3fd9fdbad752a2e02cddd648..06f1452f6653995514745e5da304ae7c0b7eb37e 100644 (file)
@@ -769,7 +769,7 @@ as internal buffering of data.
    .. versionadded:: 3.3
 
 
-.. function:: fdlistdir(fd)
+.. function:: flistdir(fd)
 
    Like :func:`listdir`, but uses a file descriptor instead and always returns
    strings.
index c20c889550baccc3b72b93b90452e34d43f988dc..d3044b3f99af1834237ed2b4f60dffd3dd849a94 100644 (file)
@@ -571,7 +571,7 @@ os
 
 * Other new functions:
 
-  * :func:`~os.fdlistdir` (:issue:`10755`)
+  * :func:`~os.flistdir` (:issue:`10755`)
   * :func:`~os.getgrouplist` (:issue:`9344`)
 
 
index ad5d5381c042126fe0e9765f16c36f19b93662df..301870cb48731cf58fe61ef1e22d3fe74947b3ed 100644 (file)
--- a/Misc/NEWS
+++ b/Misc/NEWS
@@ -1745,7 +1745,7 @@ Library
 
 - Issue #11297: Add collections.ChainMap().
 
-- Issue #10755: Add the posix.fdlistdir() function.  Patch by Ross Lagerwall.
+- Issue #10755: Add the posix.flistdir() function.  Patch by Ross Lagerwall.
 
 - Issue #4761: Add the *at() family of functions (openat(), etc.) to the posix
   module.  Patch by Ross Lagerwall.
index 2269fe90218455534cdd711a591a3f0cd52557f8..2251a626d6b5a9ae0b2d99dece0ecd1401095506 100644 (file)
@@ -2867,12 +2867,12 @@ posix_listdir(PyObject *self, PyObject *args)
 }  /* end of posix_listdir */
 
 #ifdef HAVE_FDOPENDIR
-PyDoc_STRVAR(posix_fdlistdir__doc__,
-"fdlistdir(fd) -> list_of_strings\n\n\
+PyDoc_STRVAR(posix_flistdir__doc__,
+"flistdir(fd) -> list_of_strings\n\n\
 Like listdir(), but uses a file descriptor instead.");
 
 static PyObject *
-posix_fdlistdir(PyObject *self, PyObject *args)
+posix_flistdir(PyObject *self, PyObject *args)
 {
     PyObject *d, *v;
     DIR *dirp;
@@ -2880,7 +2880,7 @@ posix_fdlistdir(PyObject *self, PyObject *args)
     int fd;
 
     errno = 0;
-    if (!PyArg_ParseTuple(args, "i:fdlistdir", &fd))
+    if (!PyArg_ParseTuple(args, "i:flistdir", &fd))
         return NULL;
     /* closedir() closes the FD, so we duplicate it */
     fd = dup(fd);
@@ -10555,7 +10555,7 @@ static PyMethodDef posix_methods[] = {
 #endif /* HAVE_LINK */
     {"listdir",         posix_listdir, METH_VARARGS, posix_listdir__doc__},
 #ifdef HAVE_FDOPENDIR
-    {"fdlistdir",       posix_fdlistdir, METH_VARARGS, posix_fdlistdir__doc__},
+    {"flistdir",       posix_flistdir, METH_VARARGS, posix_flistdir__doc__},
 #endif
     {"lstat",           posix_lstat, METH_VARARGS, posix_lstat__doc__},
     {"mkdir",           posix_mkdir, METH_VARARGS, posix_mkdir__doc__},
--- a/Lib/os.py
+++ b/Lib/os.py
@@ -357,7 +357,7 @@ if _exists("openat"):
         # whether to follow symlinks
         flag = 0 if followlinks else AT_SYMLINK_NOFOLLOW
 
-        names = fdlistdir(topfd)
+        names = flistdir(topfd)
         dirs, nondirs = [], []
         for name in names:
             # Here, we don't use AT_SYMLINK_NOFOLLOW to be consistent with
index 7f955d1e90fc2be9c38acfd106eb4c08bddd6378..8b07c773468bac8fc21faca2671aef94ab9fbee4 100644 (file)
@@ -611,8 +611,8 @@ class FwalkTests(WalkTests):
             for root, dirs, files, rootfd in os.fwalk(*args):
                 # check that the FD is valid
                 os.fstat(rootfd)
-                # check that fdlistdir() returns consistent information
-                self.assertEqual(set(os.fdlistdir(rootfd)), set(dirs) | set(files))
+                # check that flistdir() returns consistent information
+                self.assertEqual(set(os.flistdir(rootfd)), set(dirs) | set(files))
 
     def test_fd_leak(self):
         # Since we're opening a lot of FDs, we must be careful to avoid leaks:
index f8c6baa08306a7c841bca0d00c9c1c317fb96e82..c3dfffb1784537ededc59febe193f34f48580c84 100644 (file)
@@ -451,18 +451,18 @@ class PosixTester(unittest.TestCase):
         if hasattr(posix, 'listdir'):
             self.assertTrue(support.TESTFN in posix.listdir())
 
-    @unittest.skipUnless(hasattr(posix, 'fdlistdir'), "test needs posix.fdlistdir()")
-    def test_fdlistdir(self):
+    @unittest.skipUnless(hasattr(posix, 'flistdir'), "test needs posix.flistdir()")
+    def test_flistdir(self):
         f = posix.open(posix.getcwd(), posix.O_RDONLY)
         self.addCleanup(posix.close, f)
         self.assertEqual(
             sorted(posix.listdir('.')),
-            sorted(posix.fdlistdir(f))
+            sorted(posix.flistdir(f))
             )
         # Check that the fd offset was reset (issue #13739)
         self.assertEqual(
             sorted(posix.listdir('.')),
-            sorted(posix.fdlistdir(f))
+            sorted(posix.flistdir(f))
             )
 
     def test_access(self):
index 84b16d3e0fc8da64842ae471dece15df5b5e7b94..32ed577ef4ebae4cb0da579645bd45d23cc3c06e 100644 (file)